Title: [243491] trunk
Revision
243491
Author
carlo...@webkit.org
Date
2019-03-26 04:18:29 -0700 (Tue, 26 Mar 2019)

Log Message

Unreviewed. Fix typo in GLib geolocation API after r243285.

gelocation -> geolocation.

Source/WebKit:

* UIProcess/API/glib/WebKitGeolocationManager.cpp:
(webkit_geolocation_manager_class_init):
(webkit_geolocation_manager_update_position):
(webkit_geolocation_manager_failed):
(webkit_gelocation_manager_update_position): Deleted.
(webkit_gelocation_manager_failed): Deleted.
* UIProcess/API/gtk/WebKitGeolocationManager.h:
* UIProcess/API/gtk/docs/webkit2gtk-4.0-sections.txt:
* UIProcess/API/wpe/WebKitGeolocationManager.h:
* UIProcess/API/wpe/docs/wpe-1.0-sections.txt:

Tools:

* TestWebKitAPI/Tests/WebKitGLib/TestGeolocationManager.cpp:
(testGeolocationManagerWatchPosition):

Modified Paths

Diff

Modified: trunk/Source/WebKit/ChangeLog (243490 => 243491)


--- trunk/Source/WebKit/ChangeLog	2019-03-26 10:16:46 UTC (rev 243490)
+++ trunk/Source/WebKit/ChangeLog	2019-03-26 11:18:29 UTC (rev 243491)
@@ -1,3 +1,20 @@
+2019-03-26  Carlos Garcia Campos  <cgar...@igalia.com>
+
+        Unreviewed. Fix typo in GLib geolocation API after r243285.
+
+        gelocation -> geolocation.
+
+        * UIProcess/API/glib/WebKitGeolocationManager.cpp:
+        (webkit_geolocation_manager_class_init):
+        (webkit_geolocation_manager_update_position):
+        (webkit_geolocation_manager_failed):
+        (webkit_gelocation_manager_update_position): Deleted.
+        (webkit_gelocation_manager_failed): Deleted.
+        * UIProcess/API/gtk/WebKitGeolocationManager.h:
+        * UIProcess/API/gtk/docs/webkit2gtk-4.0-sections.txt:
+        * UIProcess/API/wpe/WebKitGeolocationManager.h:
+        * UIProcess/API/wpe/docs/wpe-1.0-sections.txt:
+
 2019-03-26  Patrick Griffis  <pgrif...@igalia.com>
 
         [GTK][WPE] Disable process warming

Modified: trunk/Source/WebKit/UIProcess/API/glib/WebKitGeolocationManager.cpp (243490 => 243491)


--- trunk/Source/WebKit/UIProcess/API/gtk/WebKitGeolocationManager.h	2019-03-26 10:16:46 UTC (rev 243490)
+++ trunk/Source/WebKit/UIProcess/API/gtk/WebKitGeolocationManager.h	2019-03-26 11:18:29 UTC (rev 243491)
@@ -63,11 +63,11 @@
 webkit_geolocation_manager_get_type                 (void);
 
 WEBKIT_API void
-webkit_gelocation_manager_update_position           (WebKitGeolocationManager  *manager,
+webkit_geolocation_manager_update_position           (WebKitGeolocationManager  *manager,
                                                      WebKitGeolocationPosition *position);
 
 WEBKIT_API void
-webkit_gelocation_manager_failed                    (WebKitGeolocationManager  *manager,
+webkit_geolocation_manager_failed                    (WebKitGeolocationManager  *manager,
                                                      const char                *error_message);
 
 WEBKIT_API gboolean

Modified: trunk/Source/WebKit/UIProcess/API/gtk/docs/webkit2gtk-4.0-sections.txt (243490 => 243491)


--- trunk/Source/WebKit/UIProcess/API/gtk/docs/webkit2gtk-4.0-sections.txt	2019-03-26 10:16:46 UTC (rev 243490)
+++ trunk/Source/WebKit/UIProcess/API/gtk/docs/webkit2gtk-4.0-sections.txt	2019-03-26 11:18:29 UTC (rev 243491)
@@ -1497,8 +1497,8 @@
 <SECTION>
 <FILE>WebKitGeolocationManager</FILE>
 WebKitGeolocationManager
-webkit_gelocation_manager_update_position
-webkit_gelocation_manager_failed
+webkit_geolocation_manager_update_position
+webkit_geolocation_manager_failed
 webkit_geolocation_manager_get_enable_high_accuracy
 
 <SUBSECTION Position>

Modified: trunk/Source/WebKit/UIProcess/API/wpe/WebKitGeolocationManager.h (243490 => 243491)


--- trunk/Source/WebKit/UIProcess/API/wpe/WebKitGeolocationManager.h	2019-03-26 10:16:46 UTC (rev 243490)
+++ trunk/Source/WebKit/UIProcess/API/wpe/WebKitGeolocationManager.h	2019-03-26 11:18:29 UTC (rev 243491)
@@ -63,11 +63,11 @@
 webkit_geolocation_manager_get_type                 (void);
 
 WEBKIT_API void
-webkit_gelocation_manager_update_position           (WebKitGeolocationManager  *manager,
+webkit_geolocation_manager_update_position           (WebKitGeolocationManager  *manager,
                                                      WebKitGeolocationPosition *position);
 
 WEBKIT_API void
-webkit_gelocation_manager_failed                    (WebKitGeolocationManager  *manager,
+webkit_geolocation_manager_failed                    (WebKitGeolocationManager  *manager,
                                                      const char                *error_message);
 
 WEBKIT_API gboolean

Modified: trunk/Source/WebKit/UIProcess/API/wpe/docs/wpe-1.0-sections.txt (243490 => 243491)


--- trunk/Source/WebKit/UIProcess/API/wpe/docs/wpe-1.0-sections.txt	2019-03-26 10:16:46 UTC (rev 243490)
+++ trunk/Source/WebKit/UIProcess/API/wpe/docs/wpe-1.0-sections.txt	2019-03-26 11:18:29 UTC (rev 243491)
@@ -1371,8 +1371,8 @@
 <SECTION>
 <FILE>WebKitGeolocationManager</FILE>
 WebKitGeolocationManager
-webkit_gelocation_manager_update_position
-webkit_gelocation_manager_failed
+webkit_geolocation_manager_update_position
+webkit_geolocation_manager_failed
 webkit_geolocation_manager_get_enable_high_accuracy
 
 <SUBSECTION Position>

Modified: trunk/Tools/ChangeLog (243490 => 243491)


--- trunk/Tools/ChangeLog	2019-03-26 10:16:46 UTC (rev 243490)
+++ trunk/Tools/ChangeLog	2019-03-26 11:18:29 UTC (rev 243491)
@@ -1,3 +1,12 @@
+2019-03-26  Carlos Garcia Campos  <cgar...@igalia.com>
+
+        Unreviewed. Fix typo in GLib geolocation API after r243285.
+
+        gelocation -> geolocation.
+
+        * TestWebKitAPI/Tests/WebKitGLib/TestGeolocationManager.cpp:
+        (testGeolocationManagerWatchPosition):
+
 2019-03-25  Alex Christensen  <achristen...@webkit.org>
 
         Do not terminate the NetworkProcess if a third party application sends a NSCredential with a SecIdentityRef

Modified: trunk/Tools/TestWebKitAPI/Tests/WebKitGLib/TestGeolocationManager.cpp (243490 => 243491)


--- trunk/Tools/TestWebKitAPI/Tests/WebKitGLib/TestGeolocationManager.cpp	2019-03-26 10:16:46 UTC (rev 243490)
+++ trunk/Tools/TestWebKitAPI/Tests/WebKitGLib/TestGeolocationManager.cpp	2019-03-26 11:18:29 UTC (rev 243491)
@@ -91,12 +91,12 @@
 
         if (m_errorMessage) {
             g_assert_false(m_checkPosition);
-            webkit_gelocation_manager_failed(m_manager, m_errorMessage.get());
+            webkit_geolocation_manager_failed(m_manager, m_errorMessage.get());
         }
 
         if (m_checkPosition) {
             g_assert_false(m_errorMessage.get());
-            webkit_gelocation_manager_update_position(m_manager, m_checkPosition);
+            webkit_geolocation_manager_update_position(m_manager, m_checkPosition);
         }
 
         g_main_loop_quit(m_mainLoop);
@@ -307,7 +307,7 @@
     g_assert_true(test->m_updating);
 
     WebKitGeolocationPosition* position = webkit_geolocation_position_new(37.1760783, -3.59033, 17);
-    webkit_gelocation_manager_update_position(test->m_manager, position);
+    webkit_geolocation_manager_update_position(test->m_manager, position);
     webkit_geolocation_position_free(position);
     auto result = test->lastPosition();
     g_assert_cmpfloat(result.latitude, ==, 37.1760783);
@@ -315,7 +315,7 @@
     g_assert_cmpfloat(result.accuracy, ==, 17);
 
     position = webkit_geolocation_position_new(38.1770783, -3.60033, 17);
-    webkit_gelocation_manager_update_position(test->m_manager, position);
+    webkit_geolocation_manager_update_position(test->m_manager, position);
     webkit_geolocation_position_free(position);
     result = test->lastPosition();
     g_assert_cmpfloat(result.latitude, ==, 38.1770783);
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to
--- trunk/Source/WebKit/UIProcess/API/glib/WebKitGeolocationManager.cpp	2019-03-26 10:16:46 UTC (rev 243490)
+++ trunk/Source/WebKit/UIProcess/API/glib/WebKitGeolocationManager.cpp	2019-03-26 11:18:29 UTC (rev 243491)
@@ -41,7 +41,7 @@
  * Once a #WebKitGeolocationPermissionRequest is allowed, when WebKit needs to know the
  * user location #WebKitGeolocationManager::start signal is emitted. If the signal is handled
  * and returns %TRUE, the application is responsible for providing the position every time it's
- * updated by calling webkit_gelocation_manager_update_position(). The signal #WebKitGeolocationManager::stop
+ * updated by calling webkit_geolocation_manager_update_position(). The signal #WebKitGeolocationManager::stop
  * will be emitted when location updates are no longer needed.
  *
  * Since: 2.26
@@ -87,7 +87,7 @@
  * WebKitGeolocationPosition:
  *
  * WebKitGeolocationPosition is an opaque struct used to provide position updates to a
- * #WebKitGeolocationManager using webkit_gelocation_manager_update_position().
+ * #WebKitGeolocationManager using webkit_geolocation_manager_update_position().
  *
  * Since: 2.26
  */
@@ -254,12 +254,12 @@
     }
     manager->priv->geoclueProvider->start([manager](GeolocationPosition&& corePosition, Optional<CString> error) {
         if (error) {
-            webkit_gelocation_manager_failed(manager, error->data());
+            webkit_geolocation_manager_failed(manager, error->data());
             return;
         }
 
         WebKitGeolocationPosition position(WTFMove(corePosition));
-        webkit_gelocation_manager_update_position(manager, &position);
+        webkit_geolocation_manager_update_position(manager, &position);
     });
 }
 
@@ -359,8 +359,8 @@
      *
      * The signal is emitted to notify that @manager needs to start receiving
      * position updates. After this signal is emitted the user should provide
      * the updates using webkit_gelocation_manager_update_position() every time
      * the position changes, or use webkit_gelocation_manager_failed() in case
      * it isn't possible to determine the current position.
      *
      * If the signal is not handled, WebKit will try to determine the position
@@ -400,7 +400,7 @@
 }
 
 /**
- * webkit_gelocation_manager_update_position:
+ * webkit_geolocation_manager_update_position:
  * @manager: a #WebKitGeolocationManager
  * @position: a #WebKitGeolocationPosition
  *
@@ -408,7 +408,7 @@
  *
  * Since: 2.26
  */
-void webkit_gelocation_manager_update_position(WebKitGeolocationManager* manager, WebKitGeolocationPosition* position)
+void webkit_geolocation_manager_update_position(WebKitGeolocationManager* manager, WebKitGeolocationPosition* position)
 {
     g_return_if_fail(WEBKIT_IS_GEOLOCATION_MANAGER(manager));
     g_return_if_fail(position);
@@ -419,7 +419,7 @@
 }
 
 /**
- * webkit_gelocation_manager_failed:
+ * webkit_geolocation_manager_failed:
  * @manager: a #WebKitGeolocationManager
  * @error_message: the error message
  *
@@ -427,7 +427,7 @@
  *
  * Since: 2.26
  */
-void webkit_gelocation_manager_failed(WebKitGeolocationManager* manager, const char* errorMessage)
+void webkit_geolocation_manager_failed(WebKitGeolocationManager* manager, const char* errorMessage)
 {
     g_return_if_fail(WEBKIT_IS_GEOLOCATION_MANAGER(manager));
 
@@ -359,8 +359,8 @@
      * The signal is emitted to notify that @manager needs to start receiving
      * position updates. After this signal is emitted the user should provide
-     * the updates using webkit_gelocation_manager_update_position() every time
-     * the position changes, or use webkit_gelocation_manager_failed() in case
+     * the updates using webkit_geolocation_manager_update_position() every time
+     * the position changes, or use webkit_geolocation_manager_failed() in case
      * it isn't possible to determine the current position.
      *

Modified: trunk/Source/WebKit/UIProcess/API/gtk/WebKitGeolocationManager.h (243490 => 243491)

